
# Getting Started with CellPoint API

## Introduction

Service for interacting with CellPoint Digital's Payment Orchestration Platform (POP).

## Install the Package

The package is compatible with Python versions `3.7+`.
Install the package from PyPi using the following pip command:

```bash
pip install apimatic-cp-sdk==0.0.1
```

You can also view the package at:
https://pypi.python.org/pypi/apimatic-cp-sdk/0.0.1

## Initialize the API Client

**_Note:_** Documentation for the client can be found [here.](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/client.md)

The following parameters are configurable for the API Client:

| Parameter | Type | Description |
|  --- | --- | --- |
| environment | [`Environment`](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/README.md#environments) | The API environment. <br> **Default: `Environment.PRODUCTION`** |
| http_client_instance | `Union[Session, HttpClientProvider]` | The Http Client passed from the sdk user for making requests |
| override_http_client_configuration | `bool` | The value which determines to override properties of the passed Http Client from the sdk user |
| http_call_back | `HttpCallBack` | The callback value that is invoked before and after an HTTP call is made to an endpoint |
| timeout | `float` | The value to use for connection timeout. <br> **Default: 30** |
| max_retries | `int` | The number of times to retry an endpoint call if it fails. <br> **Default: 0** |
| backoff_factor | `float` | A backoff factor to apply between attempts after the second try. <br> **Default: 2** |
| retry_statuses | `Array of int` | The http statuses on which retry is to be done. <br> **Default: [408, 413, 429, 500, 502, 503, 504, 521, 522, 524, 408, 413, 429, 500, 502, 503, 504, 521, 522, 524]** |
| retry_methods | `Array of string` | The http methods on which retry is to be done. <br> **Default: ["GET", "PUT", "GET", "PUT"]** |
| proxy_settings | [`ProxySettings`](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/proxy-settings.md) | Optional proxy configuration to route HTTP requests through a proxy server. |
| logging_configuration | [`LoggingConfiguration`](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/logging-configuration.md) | The SDK logging configuration for API calls |
| cpd_issued_jwt_credentials | [`CpdIssuedJwtCredentials`](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/auth/oauth-2-client-credentials-grant.md) | The credential object for OAuth 2 Client Credentials Grant |
| merchant_issued_jwt_credentials | [`MerchantIssuedJwtCredentials`](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/auth/oauth-2-bearer-token.md) | The credential object for OAuth 2 Bearer token |

The API client can be initialized as follows:

### Code-Based Client Initialization

```python
import logging

from cellpointapi.cellpointapi_client import CellpointapiClient
from cellpointapi.configuration import Environment
from cellpointapi.http.auth.cpd_issued_jwt import CpdIssuedJwtCredentials
from cellpointapi.http.auth.merchant_issued_jwt import MerchantIssuedJwtCredentials
from cellpointapi.logging.configuration.api_logging_configuration import LoggingConfiguration
from cellpointapi.logging.configuration.api_logging_configuration import RequestLoggingConfiguration
from cellpointapi.logging.configuration.api_logging_configuration import ResponseLoggingConfiguration
from cellpointapi.models.oauth_scope_cpd_issued_jwt import OauthScopeCpdIssuedJwt

client = CellpointapiClient(
    cpd_issued_jwt_credentials=CpdIssuedJwtCredentials(
        oauth_client_id='OAuthClientId',
        oauth_client_secret='OAuthClientSecret',
        oauth_scopes=[
            OauthScopeCpdIssuedJwt.BUYER,
            OauthScopeCpdIssuedJwt.DASHBOARDSVIEW
        ]
    ),
    merchant_issued_jwt_credentials=MerchantIssuedJwtCredentials(
        access_token='AccessToken'
    ),
    environment=Environment.PRODUCTION,
    logging_configuration=LoggingConfiguration(
        log_level=logging.INFO,
        request_logging_config=RequestLoggingConfiguration(
            log_body=True
        ),
        response_logging_config=ResponseLoggingConfiguration(
            log_headers=True
        )
    )
)
```

### Environment-Based Client Initialization

```python
from cellpointapi.cellpointapi_client import CellpointapiClient

# Specify the path to your .env file if it’s located outside the project’s root directory.
client = CellpointapiClient.from_environment(dotenv_path='/path/to/.env')
```

See the [Environment-Based Client Initialization](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/environment-based-client-initialization.md) section for details.

## Environments

The SDK can be configured to use a different environment for making API calls. Available environments are:

### Fields

| Name | Description |
|  --- | --- |
| PRODUCTION | **Default** |

## Authorization

This API uses the following authentication schemes.

* [`cpdIssuedJWT (OAuth 2 Client Credentials Grant)`](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/auth/oauth-2-client-credentials-grant.md)
* [`merchantIssuedJWT (OAuth 2 Bearer token)`](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/auth/oauth-2-bearer-token.md)

## List of APIs

* [Apple Pay](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/apple-pay.md)
* [Payment Methods](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/payment-methods.md)
* [Authentication](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/authentication.md)
* [Bulk](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/bulk.md)
* [Cards](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/cards.md)
* [Notes](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/notes.md)
* [Orders](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/orders.md)
* [Proxy](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/proxy.md)
* [Transactions](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/transactions.md)
* [Wallet](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/controllers/wallet.md)

## SDK Infrastructure

### Configuration

* [ProxySettings](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/proxy-settings.md)
* [Environment-Based Client Initialization](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/environment-based-client-initialization.md)
* [AbstractLogger](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/abstract-logger.md)
* [LoggingConfiguration](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/logging-configuration.md)
* [RequestLoggingConfiguration](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/request-logging-configuration.md)
* [ResponseLoggingConfiguration](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/response-logging-configuration.md)

### HTTP

* [HttpResponse](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/http-response.md)
* [HttpRequest](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/http-request.md)
* [Request](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/request.md)

### Utilities

* [ApiResponse](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/api-response.md)
* [ApiHelper](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/api-helper.md)
* [HttpDateTime](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/http-date-time.md)
* [RFC3339DateTime](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/rfc3339-date-time.md)
* [UnixDateTime](https://www.github.com/sdks-io/apimatic-cp-python-sdk/tree/0.0.1/doc/unix-date-time.md)

